@@ -284,6 +284,16 @@ static gpointer  ug_plugin_curl_thread (UgPluginCurl* plugin)
 			curl_easy_setopt (curl, CURLOPT_POSTFIELDS, http->post_data);
 			curl_easy_setopt (curl, CURLOPT_POSTFIELDSIZE, strlen (http->post_data));
 		}
+		else if (http->post_file) {
+			plugin->file_stream_in = ug_fopen (http->post_file, "r");
+			if (plugin->file_stream_in) {
+				curl_easy_setopt (curl, CURLOPT_POST, TRUE);
+				curl_easy_setopt (curl, CURLOPT_READDATA, plugin->file_stream_in);
+#if defined(_WIN32) && !defined(__MINGW32__)	// for MS VC only
+				curl_easy_setopt (curl, CURLOPT_READFUNCTION , fread);
+#endif
+			}
+		}
 	}
 
 
@@ -526,6 +536,10 @@ exit:
 		fclose (plugin->file_stream);
 		plugin->file_stream = NULL;
 	}
+	if (plugin->file_stream_in) {
+		fclose (plugin->file_stream_in);
+		plugin->file_stream_in = NULL;
+	}
 
 	if (curl_code == CURLE_OK) {
 		ug_plugin_rename_file ((UgPlugin*) plugin, plugin->path_tmp, plugin->path);
